referrerpolicy=no-referrer-when-downgrade

OnlineConfig

Struct OnlineConfig 

pub struct OnlineConfig<H> {
    pub at: Option<H>,
    pub state_snapshot: Option<SnapshotConfig>,
    pub pallets: Vec<String>,
    pub transport_uris: Vec<String>,
    pub child_trie: bool,
    pub hashed_prefixes: Vec<Vec<u8>>,
    pub hashed_keys: Vec<Vec<u8>>,
    pub disable_root_check: bool,
}
Configuration of the online execution.

A state snapshot config may be present and will be written to in that case.

Fields

at: Option<H>

The block hash at which to get the runtime state. Will be latest finalized head if not provided.

state_snapshot: Option<SnapshotConfig>

An optional state snapshot file to WRITE to, not for reading. Not written if set to None.

pallets: Vec<String>

The pallets to scrape. These values are hashed and added to hashed_prefix.

transport_uris: Vec<String>

Transport URIs. Can be a single URI or multiple for load distribution.

child_trie: bool

Lookout for child-keys, and scrape them as well if set to true.

hashed_prefixes: Vec<Vec<u8>>

Storage entry key prefixes to be injected into the externalities. The hashed prefix must be given.

hashed_keys: Vec<Vec<u8>>

Storage entry keys to be injected into the externalities. The hashed key must be given.

disable_root_check: bool

Disable verifying the downloaded storage root against the block header’s state root.

The check fails build when the scraped state is incomplete or corrupted. Set this to bypass it when deliberately overwriting the state version. Use with care.